@@ -13,7 +13,7 @@ use Server::Starter::Guard;
 
 use Exporter qw(import);
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 our @EXPORT_OK = qw(start_server restart_server server_ports);
 
 my @signals_received;
@@ -83,14 +83,17 @@ sub start_server {
     my @sockenv;
     for my $hostport (@$ports) {
         my ($domain, $sa);
+        my $fd;
         my $sockopts = sub {};
-        if ($hostport =~ /^\s*(\d+)\s*$/) {
+        if ($hostport =~ /^\s*(\d+)(?:\s*=(\d+))?\s*$/) {
             # by default, only bind to IPv4 (for compatibility)
             $hostport = $1;
+            $fd = $2;
             $domain = Socket::PF_INET;
             $sa = pack_sockaddr_in $1, Socket::inet_aton("0.0.0.0");
-        } elsif ($hostport =~ /^\s*(?:\[\s*|)([^\]]*)\s*(?:\]\s*|):\s*(\d+)\s*$/) {
+        } elsif ($hostport =~ /^\s*(?:\[\s*|)([^\]]*)\s*(?:\]\s*|):\s*(\d+)(?:\s*=(\d+))?\s*$/) {
             my ($host, $port) = ($1, $2);
+            $fd = $3;
             if ($host =~ /:/) {
                 # IPv6
                 local $@;
@@ -132,7 +135,15 @@ sub start_server {
             or die "listen(2) failed:$!";
         fcntl($sock, F_SETFD, my $flags = '')
                 or die "fcntl(F_SETFD, 0) failed:$!";
-        push @sockenv, "$hostport=" . $sock->fileno;
+        if (defined $fd) {
+            POSIX::dup2($sock->fileno, $fd)
+                or die "dup2(2) failed(${fd}): $!";
+            print STDERR "socket is duplicated to file descriptor ${fd}\n";
+            close $sock;
+            push @sockenv, "$hostport=$fd";
+        } else {
+            push @sockenv, "$hostport=" . $sock->fileno;
+        }
         push @sock, $sock;
     }
     my $path_remove_guard = Server::Starter::Guard->new(
